from fastapi import APIRouter, Depends, HTTPException, Form
from sqlmodel import Session
from backend.models.models import Category
from backend.schemas.category import  CategoryRead
from backend.database import get_session

router = APIRouter()


@router.post("/", response_model=CategoryRead)
def create_category(
    name: str = Form(...),
    session: Session = Depends(get_session),
):
    category = Category(name=name)
    session.add(category)
    session.commit()
    session.refresh(category)
    return category


@router.get("/{category_id}", response_model=CategoryRead)
def read_category(category_id: int, session: Session = Depends(get_session)):
    category = session.get(Category, category_id)
    if not category:
        raise HTTPException(status_code=404, detail="Category not found")
    return category


@router.put("/{category_id}", response_model=CategoryRead)
def update_category(
    category_id: int,
    name: str = Form(None),
    session: Session = Depends(get_session),
):
    category = session.get(Category, category_id)
    if not category:
        raise HTTPException(status_code=404, detail="Category not found")

    if name:
        category.name = name
    
    session.add(category)
    session.commit()
    session.refresh(category)
    return category


@router.delete("/{category_id}")
def delete_category(category_id: int, session: Session = Depends(get_session)):
    category = session.get(Category, category_id)
    if not category:
        raise HTTPException(status_code=404, detail="Category not found")
    session.delete(category)
    session.commit()
    return {"message": "Category deleted successfully"}